"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var ReactDOM = tslib_1.__importStar(require("react-dom"));
var Modal_1 = tslib_1.__importDefault(require("../components/Modal"));
var utils_1 = require("../helpers/utils");
var connectors_1 = tslib_1.__importDefault(require("./connectors"));
var events_1 = tslib_1.__importDefault(require("./events"));
var providers_1 = require("../providers");
var WEB3_CONNECT_MODAL_ID = "WEB3_CONNECT_MODAL_ID";
var INITIAL_STATE = { show: false };
var Core = /** @class */ (function () {
    function Core(opts) {
        var _this = this;
        this.show = INITIAL_STATE.show;
        this.eventManager = new events_1.default();
        this.injectedProvider = null;
        this.network = "";
        this.lightboxOpacity = 0.4;
        this.providerOptions = {};
        this.connectTo = function (type, connector) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var opts, providerOptions, provider, error_1;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 3, , 5]);
                        opts = undefined;
                        if (type !== "injected") {
                            providerOptions = this.providerOptions && this.providerOptions[type]
                                ? this.providerOptions[type]
                                : {};
                            opts = this.network
                                ? tslib_1.__assign({ network: this.network }, providerOptions) : providerOptions;
                        }
                        return [4 /*yield*/, connector(opts)];
                    case 1:
                        provider = _a.sent();
                        return [4 /*yield*/, this.onConnect(provider)];
                    case 2:
                        _a.sent();
                        return [3 /*break*/, 5];
                    case 3:
                        error_1 = _a.sent();
                        return [4 /*yield*/, this.onError(error_1)];
                    case 4:
                        _a.sent();
                        return [3 /*break*/, 5];
                    case 5: return [2 /*return*/];
                }
            });
        }); };
        this.toggleModal = function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var d, body;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!(this.providers &&
                            this.providers.length === 1 &&
                            this.providers[0].name)) return [3 /*break*/, 2];
                        return [4 /*yield*/, this.providers[0].onClick()];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                    case 2:
                        d = typeof window !== "undefined" ? document : "";
                        body = d ? d.body || d.getElementsByTagName("body")[0] : "";
                        if (body) {
                            if (this.show) {
                                body.style.overflow = "";
                            }
                            else {
                                body.style.overflow = "hidden";
                            }
                        }
                        return [4 /*yield*/, this.updateState({ show: !this.show })];
                    case 3:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); };
        this.getProviders = function () {
            var mobile = utils_1.isMobile();
            var providers = [
                "injected",
                "walletconnect",
                "portis",
                "fortmatic",
                "squarelink"
            ];
            var _a = _this, injectedProvider = _a.injectedProvider, providerOptions = _a.providerOptions;
            var displayInjected = injectedProvider && !providerOptions.disableInjectedProvider;
            var onlyInjected = displayInjected && mobile;
            if (onlyInjected) {
                providers = ["injected"];
            }
            else {
                if (!displayInjected) {
                    providers = providers.filter(function (provider) { return provider !== "injected"; });
                }
                if (!_this.shouldDisplayProvider("walletconnect")) {
                    providers = providers.filter(function (provider) { return provider !== "walletconnect"; });
                }
                if (!_this.shouldDisplayProvider("squarelink")) {
                    providers = providers.filter(function (provider) { return provider !== "squarelink"; });
                }
                if (!_this.shouldDisplayProvider("portis")) {
                    providers = providers.filter(function (provider) { return provider !== "portis"; });
                }
                if (!_this.shouldDisplayProvider("fortmatic")) {
                    providers = providers.filter(function (provider) { return provider !== "fortmatic"; });
                }
            }
            var providersMap = providers.map(function (provider) {
                switch (provider) {
                    case "injected":
                        return {
                            name: injectedProvider,
                            onClick: function () {
                                return _this.connectTo("injected", connectors_1.default.ConnectToInjected);
                            }
                        };
                    case "walletconnect":
                        return {
                            name: "WalletConnect",
                            onClick: function () {
                                return _this.connectTo("walletconnect", connectors_1.default.ConnectToWalletConnect);
                            }
                        };
                    case "portis":
                        return {
                            name: "Portis",
                            onClick: function () { return _this.connectTo("portis", connectors_1.default.ConnectToPortis); }
                        };
                    case "squarelink":
                        return {
                            name: "Squarelink",
                            onClick: function () {
                                return _this.connectTo("squarelink", connectors_1.default.ConnectToSquarelink);
                            }
                        };
                    case "fortmatic":
                        return {
                            name: "Fortmatic",
                            onClick: function () {
                                return _this.connectTo("fortmatic", connectors_1.default.ConnectToFortmatic);
                            }
                        };
                    default:
                        return {
                            name: "",
                            onClick: function () { return tslib_1.__awaiter(_this, void 0, void 0, function () { return tslib_1.__generator(this, function (_a) {
                                return [2 /*return*/];
                            }); }); }
                        };
                }
            });
            return providersMap;
        };
        this.onError = function (error) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!this.show) return [3 /*break*/, 2];
                        return [4 /*yield*/, this.toggleModal()];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2:
                        this.eventManager.trigger("error", error);
                        return [2 /*return*/];
                }
            });
        }); };
        this.onConnect = function (provider) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!this.show) return [3 /*break*/, 2];
                        return [4 /*yield*/, this.toggleModal()];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2:
                        this.eventManager.trigger("connect", provider);
                        return [2 /*return*/];
                }
            });
        }); };
        this.onClose = function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!this.show) return [3 /*break*/, 2];
                        return [4 /*yield*/, this.toggleModal()];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2:
                        this.eventManager.trigger("close");
                        return [2 /*return*/];
                }
            });
        }); };
        this.updateState = function (state) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        Object.keys(state).forEach(function (key) {
                            _this[key] = state[key];
                        });
                        return [4 /*yield*/, window.updateWeb3ConnectModal(state)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); };
        this.resetState = function () { return _this.updateState(tslib_1.__assign({}, INITIAL_STATE)); };
        this.injectedProvider = utils_1.getInjectedProviderName();
        if (opts) {
            this.network = opts.network || "";
            this.lightboxOpacity = opts.lightboxOpacity || 0.4;
            this.providerOptions = opts.providerOptions || {};
        }
        this.providers = this.getProviders();
        this.renderModal();
    }
    Core.prototype.on = function (event, callback) {
        this.eventManager.on({
            event: event,
            callback: callback
        });
    };
    Core.prototype.shouldDisplayProvider = function (name) {
        var providerOptions = this.providerOptions;
        var providerPackage = providers_1.providerPackages[name];
        if (providerOptions) {
            var providerPackageOptions_1 = providerOptions[providerPackage.option];
            if (providerPackageOptions_1) {
                var required = providerPackage.required;
                var matches = required.filter(function (key) { return key in providerPackageOptions_1; });
                if (required.length === matches.length) {
                    var isAvailable = yield utils_1.importProviderPackage(providerPackage.name);
                    if (isAvailable) {
                        return true;
                    }
                }
            }
        }
        return false;
    };
    Core.prototype.renderModal = function () {
        var el = document.createElement("div");
        el.id = WEB3_CONNECT_MODAL_ID;
        document.body.appendChild(el);
        ReactDOM.render(React.createElement(Modal_1.default, { providers: this.providers, onClose: this.onClose, resetState: this.resetState, lightboxOpacity: this.lightboxOpacity }), document.getElementById(WEB3_CONNECT_MODAL_ID));
    };
    return Core;
}());
exports.default = Core;
//# sourceMappingURL=index.js.map